@@ -641,7 +641,7 @@ def compute_extensive_kpis(data_df = None, strat = None):
 
     ytd_ohlc_df = data_df.loc[ytd_date:].copy()
 
-    ytd_kpis = riskmetrics.get_kpi(ytd_ohlc_df[[strat]])
+    ytd_kpis = get_kpi(ytd_ohlc_df[[strat]])
 
     return_ytd_to_date = (current_values['close'] - ytd_values['close'])/ytd_values['close']
     results = {}
